#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05
#
# (C) Copyright IBM Corp. 2003,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################

MODULE="NokGSM"
RELEASE="14.1.12.1.0"    
RP=$(echo $RELEASE|sed 's/\.//g')

SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
WorkDir=$SourceDir/workdir
UITar=${SourceDir}/tarball/${MODULE}_${RP}_UI.tgz

### stamping ts
s_yyyymmdd=`(date "+%Y%m%d")`
s_hhmmss=`(date "+%H%M%S")`
mkdir -p $SourceDir/Backup
echo "$s_yyyymmdd.$s_hhmmss" > $SourceDir/Backup/.ts.txt

### get ts
TS=`cat $SourceDir/Backup/.ts.txt`
BACKUP_DIR=$SourceDir/Backup/$TS

########################################################
# Check environment settings
echo "Checking environment....."

if ! [[ -d ${FLEXPM_HOME} ]]; then
  echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
  exit 3;
fi

if ! [[ -d ${FLEXPM_BASE} ]]; then
  echo "Env variable FLEXPM_BASE must be set to appropriate dir before installation."
  exit 3;
fi

if [ -z ${DB_CONNECT} ]; then
  echo "Env variable DB_CONNECT must be set to appropriate database connection values."
  exit 3;
fi

if ! [[ -d ${NokGSM_HOME} ]]; then
  echo "Env variable NokGSM_HOME must be set to appropriate dir before installation."
  exit 3;
fi

#######################################################
# Installing updated files ...
#######################################################
date +"+ Installing Patch $MODULE $RELEASE at %T, %D ..."

echo "+ Backing up original files and installing new files..."

mkdir -p ${BACKUP_DIR}

${WorkDir}/untar.pl $SourceDir $UITar $FLEXPM_BASE $BACKUP_DIR
ret=$?

if [ $ret != 0 ]; then
  echo "+++ Error in untar.pl"
  exit 2
fi


#######################################################
# Perform custom actions ...
#######################################################

# Rebuild dd
echo "+ Rebuilding data dictionary..."
cd ${NokGSM_HOME}/peik
make dict_update
ret=$?
if [ $ret != 0 ]; then
  echo "+++ Error while performing dict_update!"
  exit 2
fi

#######################################################
# Patching is complete ...
#######################################################
date +"+ $MODULE $RELEASE upgrade is completed at %T, %D"
echo 

